The function can be used to check which combinations of standards produce a good fit.
fit_LCF(
all.samples,
all.standards,
ecosys = NULL,
amoSTD,
ex.smaller = NULL,
file.output = NULL,
best.fits = NULL,
NMRmeth,
FixNC
)A dataframe containing the result of the fitting exercise for all files.
List of all samples
List of all standards
Standards to be used for the MMM, can be Terrestrial("Terr_Nelson" or "Terr_Baldock") or Aquatic ("Aqua_Nelson" or "Aqua_Baldock")
Use at most X standards
Exclude portions smaller than a given value (decimal form), default to NULL
Possibility to have a file output, default to NULL
Possibility to output more than the best fit (e.g. the first 10 best fits), default to 1
Regions to be integrated, methods available include: "4region", "Bonanomi", "Smernik" and Molecular mixing model ("MMM").
TRUE or FALSE, for fixing or not the NC ratio on the sample fitting.